@@ -33,6 +33,7 @@ THE SOFTWARE.
 
 #include <X11/fonts/fontenc.h>
 #include "fontencI.h"
+#include "reallocarray.h"
 
 /* Functions local to this file */
 
@@ -808,7 +809,7 @@ FontEncLoad(const char *encoding_name, const char *filename)
                 for (alias = encoding->aliases; *alias; alias++)
                     numaliases++;
             }
-            new_aliases = malloc((numaliases + 2) * sizeof(char *));
+            new_aliases = Xmallocarray(numaliases + 2, sizeof(char *));
             if (new_aliases == NULL) {
                 free(new_name);
                 return NULL;
